==> gbook-0.13b.tar.bz2: gbook/gbook.i18n-sv.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "namn",
'f_origin'        => "från",
'f_ip'            => "ip",
'f_browser'       => "browser",
'f_email'         => "e-post",
'f_homepage'      => "hemsida",
'f_captcha'       => "captcha",
'f_entry'         => "inlägg",
'f_ip'            => "ip",
'f_browser'       => "browser",

# buttons
'b_submit'        => "skicka",
'b_reply'         => "svara",
'b_change'        => "ändra",
'b_delete'        => "ta bort",
'b_reset'         => "återställ",

# misc
'headline'        => "Gästbok",
'hl_create'       => "Skapa ett nytt inlägg:",
'hl_modify'       => "Ändra ett inlägg:",
'new_entry'       => "Välkommen till denna gästbok. [{{fullurl:Special:Guestbook|action=add}} ''' Klicka här'''] för att skapa ett nytt inlägg.",
'entry_okay'      => "Okej, inlägget sparades ;)",
'delete_okay'     => "Okej, inlägget raderades.",
'change_okay'     => "Okej, inlägget ändrades.",
'show_entries'    => "Visa inlägg.",
'captcha_desc'    => "Skriv in bokstäverna och siffrorna från bilden.",
'captcha_fail'    => "Tyvärr, captchat stämmer inte!",
'err_name'        => "Tyvärr, ditt namn saknas!",
'err_entry'       => "Ledsen, ditt inlägg verkar tomt!",
'err_noentry'     => "Tyvärr, det här inlägget finns inte!",
'err_captcha'     => "Ledsen, captchat är tomt!"
);

?>

==> gbook-0.14b.tar.bz2: gbook/gbook.i18n-sv.php <==
<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "namn",
'f_origin'        => "från",
'f_ip'            => "ip",
'f_browser'       => "browser",
'f_email'         => "e-post",
'f_homepage'      => "hemsida",
'f_captcha'       => "captcha",
'f_entry'         => "inlägg",
'f_ip'            => "ip",
'f_browser'       => "browser",

# buttons
'b_submit'        => "skicka",
'b_reply'         => "svara",
'b_change'        => "ändra",
'b_delete'        => "ta bort",
'b_reset'         => "återställ",

# misc
'headline'        => "Gästbok",
'hl_create'       => "Skapa ett nytt inlägg:",
'hl_modify'       => "Ändra ett inlägg:",
'new_entry'       => "Välkommen till denna gästbok. [{{fullurl:$this->myAddPage|action=add}} ''' Klicka här'''] för att skapa ett nytt inlägg.",
'entry_okay'      => "Okej, inlägget sparades ;)",
'delete_okay'     => "Okej, inlägget raderades.",
'change_okay'     => "Okej, inlägget ändrades.",
'show_entries'    => "Visa inlägg.",
'captcha_desc'    => "Skriv in bokstäverna och siffrorna från bilden.",
'captcha_fail'    => "Tyvärr, captchat stämmer inte!",
'err_name'        => "Tyvärr, ditt namn saknas!",
'err_entry'       => "Ledsen, ditt inlägg verkar tomt!",
'err_noentry'     => "Tyvärr, det här inlägget finns inte!",
'err_captcha'     => "Ledsen, captchat är tomt!"
);

?>
